/* $Workfile: BareApp.c $       $Revision: 3 $      $Modtime: 10/24/12 12:55p $  */
/*******************************************************************************

  Odin TeleSystems Inc.

  OTX Telecom Adapter Driver

  @doc OtxDriverTest

  @module

    BareApp.C

    Bare-bone OTX Application.

*******************************************************************************/

#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#include <assert.h>
#include <time.h>

#include "OsaStd.h"
#include "OsaCon.h"
#include "OsaThrd.h"
#include "OtxGeneric.h"
#include "OtxErr.h"
#include "OtxBrd.h"
#include "OtxDef.h"
#include "OtxType.h"
#include "OtxDrv.h"
#include "OtxHdlc.h"
#include "OtxT1E1.h"
#include "OtxData.h"
#include "OtxDsp.h"



/*******************************************************************************
*******************************************************************************/
void DemoCheckRc(IN OTX_RESULT result)
{
  if (OTX_FAILURE(result)) {
    printf("ERROR(%#lX [%d.%d])\n", (long unsigned int) OTX_RESULT_CODE(result), OTX_RESULT_SOURCE_ID(result), OTX_RESULT_LINE_NUM(result));
    exit(1);
  }
}



/*******************************************************************************
*******************************************************************************/
int main(int argc, char *argv[])
{
  OTX_RESULT result;
  OTX_HANDLE hBoard;
  OTX_HANDLE hAsm;
  OTX_HANDLE hDsp[4];
  OTX_INT32  i;

  printf("BareApp for Thor-8-PCIe/Vidar-55x4-ASM, %s, Odin TeleSystems Inc.\n", __DATE__);

  result = OtxDrvConnectLib(); 
  DemoCheckRc(result);

  // Open board
  result = OtxDrvOpenPhysicalDevice(0, OTX_DEVICE_THOR_8_PCIE, 0, 0, OTX_INVALID_HANDLE_VALUE, &hBoard); 
  DemoCheckRc(result);


	// Get a handle to to the ASM Daughter Board
	result = OtxDrvOpenPhysicalDevice(hBoard, OTX_DEVICE_VIDAR_55x4_ASM, 0, 0, OTX_INVALID_HANDLE_VALUE, &hAsm);
  DemoCheckRc(result);

  // Open the 4 DSPs
  for (i = 0; i < 4; i++) {
		result = OtxDrvOpenPhysicalDevice(hAsm, OTX_DEVICE_DSP, i, i, OTX_INVALID_HANDLE_VALUE, &hDsp[i]);
    DemoCheckRc(result);
	}


  result = OtxDrvEnable(hBoard,  OTX_TASK_SYNC, 5000L); 
  DemoCheckRc(result);
  result = OtxDrvEnable(hAsm,    OTX_TASK_SYNC, 5000L); 
  DemoCheckRc(result);

  for (i = 0; i < 4; i++) {
    result = OtxDrvEnable(hDsp[i], OTX_TASK_SYNC, 5000L); 
    DemoCheckRc(result);
  }

  printf("Complete\n");
  OtxDrvReleaseLib();

  return 0;
}

