/* $Workfile: OtxResult.c $   $Revision: 2 $    $Modtime: 10/24/12 12:55p $  */
/*******************************************************************************

  Copyright (c) Odin TeleSystems Inc., 2012, All Rights Reserved

  @doc internal

  @module OtxResult

  OtxResult.cpp

  Utility to parse and display the parts of the OTX_RESULT code.

*******************************************************************************/

#include <stdio.h>
#include <stdlib.h>

#include "OtxErr.h"
#include "OtxDrv.h"

// see OtxErr.h
static const char *sOtxSourceIdE[] = {
  "OTX_SRC_SOURCE_ID_NONE",
  "OTX_SRC_DRV_ODASM_CPP",
  "OTX_SRC_DRV_ODVIDAR55X4ASM_CPP",
  "OTX_SRC_DRV_ODVIDAR5X4CST_CPP",
  "OTX_SRC_DRV_ODVIDAR5X4EX_CPP",
  "OTX_SRC_DRV_ODVIDAR5X4PRO_CPP",
  "OTX_SRC_DRV_ODVIDAR5XNASM_CPP",
  "OTX_SRC_DRV_ODDEBUG_CPP",
  "OTX_SRC_DRV_ODDEVICE_CPP",
  "OTX_SRC_DRV_ODEVENTQUEUE_CPP",
  "OTX_SRC_DRV_ODHWDEVICE_CPP",
  "OTX_SRC_DRV_ODLOGICALDEVICE_CPP",
  "OTX_SRC_DRV_ODPIPE_CPP",
  "OTX_SRC_DRV_ODPNPDEVICE_CPP",
  "OTX_SRC_DRV_ODUTILS_CPP",
  "OTX_SRC_DRV_ODAIC_CPP",
  "OTX_SRC_DRV_ODALIS_CPP",
  "OTX_SRC_DRV_ODAMB_CPP",
  "OTX_SRC_DRV_ODBURST_CPP",
  "OTX_SRC_DRV_ODCODEC_CPP",
  "OTX_SRC_DRV_ODCTBUS_CPP",
  "OTX_SRC_DRV_ODDSP_CPP",
  "OTX_SRC_DRV_ODDSPC5400X_CPP",
  "OTX_SRC_DRV_ODDSPC5410A_CPP",
  "OTX_SRC_DRV_ODDSPC5416_CPP",
  "OTX_SRC_DRV_ODDSPC548C549_CPP",
  "OTX_SRC_DRV_ODDSPC54CST_CPP",
  "OTX_SRC_DRV_ODDSPC54X_CPP",
  "OTX_SRC_DRV_ODDSPC55X_CPP",
  "OTX_SRC_DRV_ODEEPROM_CPP",
  "OTX_SRC_DRV_ODEEPROMNM93CS46_CPP",
  "OTX_SRC_DRV_ODEEPROMNM93CS56_CPP",
  "OTX_SRC_DRV_ODFALC_CPP",
  "OTX_SRC_DRV_ODFALC56_CPP",
  "OTX_SRC_DRV_ODFPGASPARTAN_CPP",
  "OTX_SRC_DRV_ODFSFIFO_CPP",
  "OTX_SRC_DRV_ODISAC_CPP",
  "OTX_SRC_DRV_ODPLX_CPP",
  "OTX_SRC_DRV_ODPLX9056_CPP",
  "OTX_SRC_DRV_ODQUADFALC_CPP",
  "OTX_SRC_DRV_ODQUADFALCMEMBER_CPP",
  "OTX_SRC_DRV_ODRINGBUF_CPP",
  "OTX_SRC_DRV_ODTBC_CPP",
  "OTX_SRC_DRV_DRIVERENTRY_CPP",
  "OTX_SRC_DRV_ODDRIVER_CPP",
  "OTX_SRC_DRV_ODDRIVERDEVICE_CPP",
  "OTX_SRC_DRV_ODE1ABCDBITACCESS_CPP",
  "OTX_SRC_DRV_ODE1SBITACCESS_CPP",
  "OTX_SRC_DRV_ODFALCE1ABCDBITACCESS_CPP",
  "OTX_SRC_DRV_ODFALCE1SBITACCESS_CPP",
  "OTX_SRC_DRV_ODFALCHDLCRECEIVER_CPP",
  "OTX_SRC_DRV_ODFALCHDLCSENDER_CPP",
  "OTX_SRC_DRV_ODFALCT1DLBITACCESS_CPP",
  "OTX_SRC_DRV_ODFALCT1ROBBITACCESS_CPP",
  "OTX_SRC_DRV_ODHDLCDEVICE_CPP",
  "OTX_SRC_DRV_ODHDLCRECEIVER_CPP",
  "OTX_SRC_DRV_ODHDLCSENDER_CPP",
  "OTX_SRC_DRV_ODRAWDATA_CPP",
  "OTX_SRC_DRV_ODRAWDATARECEIVER_CPP",
  "OTX_SRC_DRV_ODRAWDATASENDER_CPP",
  "OTX_SRC_DRV_ODSPM1CONSTVALGENERATOR_CPP",
  "OTX_SRC_DRV_ODSPM1DATACONVERTER_CPP",
  "OTX_SRC_DRV_ODSPM1DTMFDETECTOR_CPP",
  "OTX_SRC_DRV_ODSPM1DTMFDIALER_CPP",
  "OTX_SRC_DRV_ODSPM1DUALDETECTOR_CPP",
  "OTX_SRC_DRV_ODSPM1EFFECTSGENERATOR_CPP",
  "OTX_SRC_DRV_ODSPM1FSKDETECTOR_CPP",
  "OTX_SRC_DRV_ODSPM1HDLCRECEIVER_CPP",
  "OTX_SRC_DRV_ODSPM1HDLCSENDER_CPP",
  "OTX_SRC_DRV_ODSPM1MFDETECTOR_CPP",
  "OTX_SRC_DRV_ODSPM1MFDIALER_CPP",
  "OTX_SRC_DRV_ODSPM1RAWDATARECEIVER_CPP",
  "OTX_SRC_DRV_ODSPM1RAWDATASENDER_CPP",
  "OTX_SRC_DRV_ODSPM1SILENCEDETECTOR_CPP",
  "OTX_SRC_DRV_ODSPM1SINEWAVEGENERATOR_CPP",
  "OTX_SRC_DRV_ODSPM1SINGLEDETECTOR_CPP",
  "OTX_SRC_DRV_ODSPM1VALSAMPLER_CPP",
  "OTX_SRC_DRV_ODSPMLOGICALDEVICE_CPP",
  "OTX_SRC_DRV_ODT1DLBITACCESS_CPP",
  "OTX_SRC_DRV_ODT1E1BITACCESS_CPP",
  "OTX_SRC_DRV_ODT1ROBBITACCESS_CPP",
  "OTX_SRC_DRV_ODUSERAPPLICATION_CPP",
  "OTX_SRC_DRV_ODNIC_CPP",
  "OTX_SRC_DRV_ODARNI32PCI_CPP",
  "OTX_SRC_DRV_ODBALDER8SPCI_CPP",
  "OTX_SRC_DRV_ODBALDER8UPCI_CPP",
  "OTX_SRC_DRV_ODHERMODPCI_CPP",
  "OTX_SRC_DRV_ODNIC1BUS_CPP",
  "OTX_SRC_DRV_ODTHOR2PCI_CPP",
  "OTX_SRC_DRV_ODTHOR8PCI_CPP",
  "OTX_SRC_DRV_ODVIDAR5XNPCI_CPP",
  "OTX_SRC_DRV_ODNICPCMCIA_CPP",
  "OTX_SRC_DRV_ODTHOR2PCMCIA_CPP",
  "OTX_SRC_DRV_ODTHOR2PCMCIAPLUS_CPP",
  "OTX_SRC_DRV_ODTHOR2PCMCIAPLUSC549_CPP",
  "OTX_SRC_DRV_ODTHOR2PCMCIAPLUSCST_CPP",
  "OTX_SRC_DRV_ODTHOR2PCMCIAPLUSEX_CPP",
  "OTX_SRC_DRV_ODTHOR2PCMCIAPLUSPRO_CPP",
  "OTX_SRC_DRV_ODTHOR2PCMCIASTD_CPP",
  "OTX_SRC_DRV_ODNICPLUS_CPP",
  "OTX_SRC_DRV_ODSLEIPNIR_CPP",
  "OTX_SRC_DRV_ODTHOR8PCIPLUS_CPP",
  "OTX_SRC_LIB_OTXBRD_C",
  "OTX_SRC_LIB_OTXBRI_C",
  "OTX_SRC_LIB_OTXBURST_C",
  "OTX_SRC_LIB_OTXDATA_C",
  "OTX_SRC_LIB_OTXDRV_C",
  "OTX_SRC_LIB_OTXDSP_C",
  "OTX_SRC_LIB_OTXHDLC_C",
  "OTX_SRC_LIB_OTXJTAG_C",
  "OTX_SRC_LIB_OTXPOTS_C",
  "OTX_SRC_LIB_OTXRAW_C",
  "OTX_SRC_LIB_OTXT1E1_C",
  "OTX_SRC_LIB_OTXTONE_C",
  "OTX_SRC_LIB_OTXTST_C",
  "OTX_SRC_DRV_ODASM_H",
  "OTX_SRC_DRV_ODDEVICE_H",
  "OTX_SRC_DRV_ODFIFO_H",
  "OTX_SRC_DRV_ODHWDEVICE_H",
  "OTX_SRC_DRV_ODLOGICALDEVICE_H",
  "OTX_SRC_DRV_ODPNPDEVICE_H",
  "OTX_SRC_DRV_ODDSP_H",
  "OTX_SRC_DRV_ODFALC_H",
  "OTX_SRC_DRV_ODPLX_H",
  "OTX_SRC_DRV_ODE1ABCDBITACCESS_H",
  "OTX_SRC_DRV_ODE1SBITACCESS_H",
  "OTX_SRC_DRV_ODHDLCRECEIVER_H",
  "OTX_SRC_DRV_ODHDLCSENDER_H",
  "OTX_SRC_DRV_ODT1DLBITACCESS_H",
  "OTX_SRC_DRV_ODT1ROBBITACCESS_H",
  "OTX_SRC_DRV_ODNIC_H",
  "OTX_SRC_DRV_ODNIC1BUS_H",
  "OTX_SRC_DRV_ODTHOR2PCMCIA_H",
  "OTX_SRC_DRV_ODTHOR2PCMCIAPLUS_H",
  "OTX_SRC_LIB_OTXLIB_H",
  "OTX_SRC_DRV_ODFALC56_H",
  "OTX_SRC_DRV_ODGIMLE16PCIPLUS_CPP",
  "OTX_SRC_LIB_OSABOARD_C",
  "OTX_SRC_OSA_OSANDISOID_CPP",
  "OTX_SRC_DRV_ODARNI6X6PCIPLUS_CPP",
  "OTX_SRC_DRV_ODCSTDTMFDETECTOR_CPP",
  "OTX_SRC_LIB_OTXCST_C",
  "OTX_SRC_DRV_ODCSTPOTSLI_CPP",
  "OTX_SRC_DRV_ODCSTCALLERID_CPP",      
  "OTX_SRC_DRV_ODCSTDTMFDIALER_CPP",    
  "OTX_SRC_DRV_ODCSTVOICEACTIVITYDETECTOR_CPP",
  "OTX_SRC_DRV_ODCSTCOMFORTNOISEGENERATOR_CPP",
  "OTX_SRC_DRV_ODCSTVOICEMIXER_CPP",
  "OTX_SRC_DRV_ODCSTECHOCANCEL_CPP",
  "OTX_SRC_DRV_ODCSTCPTDETECTOR_CPP",
  "OTX_SRC_DRV_ODCSTCPTGENERATOR_CPP",
  "OTX_SRC_DRV_ODPROSLIC_CPP",
  "OTX_SRC_LIB_OTXSLIC_C",
  "OTX_SRC_DRV_ODCSTCIDDETECTOR_CPP", 
  "OTX_SRC_DRV_ODHUGIN2PC104_CPP",
  "OTX_SRC_DRV_ODTHOR2EXPRESSCARD_CPP",
  "OTX_SRC_DRV_ODTHOREXPRESSCARD_CPP",
  "OTX_SRC_DRV_ODTHOR4EXPRESSCARD_CPP",
  "OTX_SRC_DRV_ODDAVINCIDMP_CPP",
  "OTX_SRC_DRV_ODDAVINCIASP_CPP",
  "OTX_SRC_DRV_ODDAVINCISPI_CPP",
  "OTX_SRC_DRV_ODVIDARALVIS_CPP",
  "OTX_SRC_DRV_ODAMBT8100_CPP",
  "OTX_SRC_DRV_ODAMBT8110L_CPP",
  "OTX_SRC_DRV_ODAMBT8100_CPP",
  "OTX_SRC_DRV_ODAMB_H",
  "OTX_SRC_LIB_OTXDMP_C",
  "OTX_SRC_DRV_ODALVISASM_CPP",
  "OTX_SRC_DRV_ODZLETHSW_CPP",
  "OTX_SRC_DRV_ODDAVINCIHPI_CPP",
  "OTX_SRC_DRV_ODDAVINCIOTP_CPP",
  "OTX_SRC_DRV_ODDSPDM644X_CPP",
  "OTX_SRC_DRV_ODDSPDM644XHOST_CPP",
  "OTX_SRC_DRV_ODDSPDM644XDAVINCI_CPP",
  "OTX_SRC_DRV_ODDSPDM644X_H",
  "OTX_SRC_OSA_OSAWDM_CPP",
  "OTX_SRC_OSA_OSAWIN32_CPP",
  "OTX_SRC_DRV_ODTHOR2PCIPLUS_CPP",
  "OTX_SRC_DRV_ODCODECLE58Q_CPP",
  "OTX_SRC_LIB_OTXETH_C",
  "OTX_SRC_DRV_ODALVISPCIEXPRESS_CPP",
  "OTX_SRC_DRV_ODALVISPCIEXPRESS_H",
  "OTX_SRC_DRV_ODALVIS4CSI_CPP",
  "OTX_SRC_DRV_ODDAVINCITEMPSENSOR_CPP",
  "OTX_SRC_DRV_ODFALCRAWDATARECEIVER_CPP",
  "OTX_SRC_DRV_ODALVISHOSTED_CPP",
  "OTX_SRC_DRV_ODDAVINCIIOEXPANDER_CPP",
  "OTX_SRC_DRV_ODALVIS8CSI_CPP",
  "OTX_SRC_DRV_ODALVISCSI_CPP",
  "OTX_SRC_DRV_ODDAVINCIIOEXPANDER24_CPP",
  "OTX_SRC_DRV_ODALVISCSI_H",
  "OTX_SRC_DRV_ODQUADFALCMEMBER_H",
  "OTX_SRC_DRV_ODOTPDAEMONINTERFACE_CPP",
  "OTX_SRC_DRV_ODGODARPCIEXPRESS_CPP",
  "OTX_SRC_DRV_ODGODARPCIEXPRESS_H",
  "OTX_SRC_DRV_ODDMA_CPP",
  "OTX_SRC_DRV_ODDMA_H",
  "OTX_SRC_DRV_ODTEMUX_CPP",
  "OTX_SRC_DRV_ODTEMUX_H",
};

int main(int argc, char *argv[])
{
  OTX_RESULT otxRc;
  OTX_UINT32 Result, Severity, SourceId, LineNum;

  if ((sizeof(sOtxSourceIdE) / sizeof(sOtxSourceIdE[0])) != OTX_SRC_SOURCE_ID_COUNT) {    // allow for [0]
    printf("\n\nWARNING! sOtxSourceIdEneeds updating from OtxSourceIdE!\n\n");
  }

// the output is valid for all versions
#if 0
  {
    char szLibRevStr[80];

    szLibRevStr[0] = 0;
    otxRc = OtxDrvGetAttributeValueSz(OTX_LIB_HANDLE, OTX_ATTR_LIB_REV_STR, szLibRevStr, sizeof(szLibRevStr) - 1);
    printf("NOTE!  The output is only valid for Revision: %s\n\n", szLibRevStr);
  }
#endif

  printf("Enter the OTX_RESULT hexadecimalnumber: ");
  scanf("%x", &otxRc);
  OtxResultCode(otxRc, &Result, &Severity, &SourceId, &LineNum);

  printf("\n%#lX:\n", (long unsigned int) otxRc);
  printf(" ERROR:      %#lX\n", (long unsigned int) Result);
  printf(" Source ID:  %d (%s)\n", SourceId, SourceId < (sizeof(sOtxSourceIdE) / sizeof(sOtxSourceIdE[0])) ? sOtxSourceIdE[SourceId] : "unknown");
  printf(" Line #:     %d\n", LineNum);

  return 0;
}

