/* $Workfile: OsaLinuxDef.h $   $Revision: 2 $    $Modtime: 4/02/13 9:27a $  */
#ifndef OSA_LINUX_DEF_H
#define OSA_LINUX_DEF_H
/*******************************************************************************

  @doc PublicHwApi OsaLinuxDef

  Copyright (C) 1999-2013 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OsaLinuxDef | This file contains types and macros for the Linux
  version of the platform generic Osa implementation 
  (used by the demo programs)

  @contents2
  OsaLinuxDef.h |

  @index func | OsaLinuxDef

  @contents2
  Linux Osa Types and Macros | Types and macros for the Linux
  version of the platform generic Osa implementation 
  (used by the demo programs)

*******************************************************************************/
#if !OSA_LINUX
#error "This file should only be included in OSA_LINUX configurations"
#endif


#define OSA_CDECL

// *** NO LINUX KERNEL INCLUDES IN CPP CODE ***

#ifdef __cplusplus
extern "C" {
#endif


// All Linux configurations use the same types
// But we need the correct system header for it
// Different Linux configurations are compiled using different INCLUDE paths
// It's not nice to include another header (especialy not a systeim header) in
// one of our 'def' files, but that's the easiest way to get architecture
// independence under Linux.
#ifndef _ASM_GENERIC_INT_LL64_H
  typedef unsigned long long __u64;
  typedef unsigned int __u32;
  typedef unsigned short __u16;
  typedef unsigned char __u8;

  typedef long long __s64;
  typedef int __s32;
  typedef short __s16;
  typedef char __s8;

  typedef unsigned int u32;
  typedef unsigned short u16;

  typedef long unsigned int size_t;
#endif

  typedef struct {
#ifdef CONFIG_X86_32
    int counter;
#else
    long long counter;
#endif
  } osalinux_atomic_t;

  int osalinux_atomic_read(const osalinux_atomic_t *v);
  void osalinux_atomic_set(osalinux_atomic_t *v, int i);
  void osalinux_atomic_add(int i, osalinux_atomic_t *v);
  void osalinux_atomic_sub(int i, osalinux_atomic_t *v);
  void osalinux_atomic_inc(osalinux_atomic_t *v);
  void osalinux_atomic_dec(osalinux_atomic_t *v);

  int osalinux_printk(const char *format, ...);
  void *memcpy(void *dest, const void *src, size_t n);
  void *memset(void *s, int c, size_t n);
  int memcmp(const void *s1, const void *s2, size_t n);

#ifndef NULL
#define NULL 0
#endif

#ifdef __cplusplus
}
#endif

typedef __u64   OsaUint64;
typedef __u32   OsaUint32;
typedef __u16   OsaUint16;
typedef __u8    OsaUint8;
typedef __s64   OsaInt64;
typedef __s32   OsaInt32;
typedef __s16   OsaInt16;
typedef __s8    OsaInt8;
typedef double  OsaFp64;
typedef void    OsaVoid, *OsaVoidP;
typedef void    *OsaPMDL;
typedef unsigned long OsaWchar, *OsaWcharP;

typedef unsigned long OsaULong;   //32 bits in 32-bit system; 64 bits in 64-bit system

/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1999-2013

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif // OSA_LINUX_DEF_H
