/* $Workfile: OtxGeneric.h $   $Revision: 1 $    $Modtime: 9/24/09 2:45p $  */
#ifndef OTX_GENERIC_H
#define OTX_GENERIC_H
/*******************************************************************************

  Copyright (C) 1998, 1999 Odin TeleSystems Inc., All Rights Reserved.

  @doc PublicHwApi OtxGeneric

  OTX Generic Hardware Driver API

  @module
  OtxGeneric | Generic functions and macros provided in the OTX driver API

  @contents2
  OtxGeneric.h |

  @index func | OtxGeneric

  @contents2
  OTX Generic Functions/Macros |

  @index func | OtxGeneric

*******************************************************************************/

// Macros for Checking Handle types
// @func OTX_BOOL | OTX_PHYSICAL_DEVICE_HANDLE | Check if a Handle of type OTX_HANDLE is a Handle to a Physical Device
// @parm OTX_HANDLE | hDevice | A handle to any type device
#define OTX_PHYSICAL_DEVICE_HANDLE(h)   (((h) & OTX_HANDLE_DMASK) == (OTX_HANDLE_TYPE_PHYSICAL << (OTX_HANDLE_UMASK_BITS + OTX_HANDLE_IMASK_BITS)))

// @func OTX_BOOL | OTX_LOGICAL_DEVICE_HANDLE | Check if a Handle of type OTX_HANDLE is a Handle to a Logical Device
// @parm OTX_HANDLE | hDevice | A handle to any type device
#define OTX_LOGICAL_DEVICE_HANDLE(h)    (((h) & OTX_HANDLE_DMASK) == (OTX_HANDLE_TYPE_LOGICAL << (OTX_HANDLE_UMASK_BITS + OTX_HANDLE_IMASK_BITS)))

// @func OTX_BOOL | OTX_QUEUE_HANDLE | Check if a Handle of type OTX_HANDLE is a Handle to a Queue
// @parm OTX_HANDLE | hDevice | A handle to any type device
#define OTX_QUEUE_HANDLE(h)             (((h) & OTX_HANDLE_DMASK) == (OTX_HANDLE_TYPE_EVENTQUEUE << (OTX_HANDLE_UMASK_BITS + OTX_HANDLE_IMASK_BITS)))

// @func OTX_BOOL | OTX_PIPE_HANDLE | Check if a Handle of type OTX_HANDLE is a Handle to a Pipe
// @parm OTX_HANDLE | hDevice | A handle to any type device
#define OTX_PIPE_HANDLE(h)              (((h) & OTX_HANDLE_DMASK) == (OTX_HANDLE_TYPE_PIPE << (OTX_HANDLE_UMASK_BITS + OTX_HANDLE_IMASK_BITS)))

// @func OTX_BOOL | OTX_SERVICE_HANDLE | Check if a Handle of type OTX_HANDLE is a Handle to a Service
// @parm OTX_HANDLE | hDevice | A handle to any type device
#define OTX_SERVICE_HANDLE(h)           (((h) & OTX_HANDLE_DMASK) == (OTX_HANDLE_TYPE_SERVICE << (OTX_HANDLE_UMASK_BITS + OTX_HANDLE_IMASK_BITS)))

// @func OTX_BOOL | OTX_CALL_HANDLE | Check if a Handle of type OTX_HANDLE is a Handle to a Call
// @parm OTX_HANDLE | hDevice | A handle to any type device
#define OTX_CALL_HANDLE(h)              (((h) & OTX_HANDLE_DMASK) == (OTX_HANDLE_TYPE_CALL << (OTX_HANDLE_UMASK_BITS + OTX_HANDLE_IMASK_BITS)))

// @func int | OTX_VALID_HANDLE | Check if a Handle of type OTX_HANDLE is a valid Handle
// @parm OTX_HANDLE | hDevice | A handle to any type device
#define OTX_VALID_HANDLE(h) (OTX_QUEUE_HANDLE(h) || OTX_PIPE_HANDLE(h) || OTX_LOGICAL_DEVICE_HANDLE(h) || OTX_PHYSICAL_DEVICE_HANDLE(h) || OTX_SERVICE_HANDLE(h) || OTX_CALL_HANDLE(h))

// @func OTX_HANDLE | OTX_GET_HANDLE_VAL | Retrieve the value of a Handle of type OTX_HANDLE
// @parm OTX_HANDLE | hDevice | A handle to any type device
#define OTX_GET_HANDLE_VAL(h)   ( (OTX_HANDLE) ((h) & OTX_HANDLE_IMASK) )


// @func StructType * | OTX_STRUCT_ADD_BYTE_OFFSET | 
// Macro that takes care of type casting when adding a byte offset to a struct pointer
// to find a second struct at another location
// e.g.:
// OtxHdlcFrameInfoS p1 = buffer;
// OtxHdlcFrameInfoS p2 = OTX_STRUCT_ADD_BYTE_OFFSET(OtxHdlcFrameInfoS, p1, p1->nOffsetNext);
// @parm StructType | StructType | The name of the type of the structure whose base address is to be returned
// @parm OTX_UINT8 * | pBase | Base Address of the structure pointer
// @parm OTX_UINT8 | nByteOffset | Byte offset from Base Address that the second structure is located
#define OTX_STRUCT_ADD_BYTE_OFFSET(StructType, pBase, nByteOffset) /*
*/  ((StructType *) (((OTX_UINT8 *) pBase) + nByteOffset))


#define OTX_HANDLE_DMASK 0xF0000000    // Device Type Mask
#define OTX_HANDLE_UMASK 0x0FFF0000    // Uniqueness Value Mask
#define OTX_HANDLE_IMASK 0x0000FFFF    // Index Value Mask

#define OTX_HANDLE_DMASK_BITS 4
#define OTX_HANDLE_UMASK_BITS 12
#define OTX_HANDLE_IMASK_BITS 16

// Note that a zero handle and OTX_INVALID_HANDLE_VALUE are both used to refer
// to the single driver device that represents the OTX driver. The actual handle for
// that device is cached in the library with which the application links after the call
// to OtxConnectLib
//
#define OTX_HANDLE_TYPE_PHYSICAL    1
#define OTX_HANDLE_TYPE_LOGICAL     2
#define OTX_HANDLE_TYPE_EVENTQUEUE  3
#define OTX_HANDLE_TYPE_PIPE        4
#define OTX_HANDLE_TYPE_SERVICE     5
#define OTX_HANDLE_TYPE_CALL        6

/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1998, 1999

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif // OTX_GENERIC_H

